@@ -1,11 +1,14 @@
 package SQL::Statement::Placeholder;
 
+use strict;
+use warnings;
+
 use vars qw(@ISA);
 require Carp;
 
 require SQL::Statement::Term;
 
-our $VERSION = '1.27_02';
+our $VERSION = '1.400';
 
 @ISA = qw(SQL::Statement::Term);
 
